/** @file
  * 
  * @brief    Firmware configuration
  *
  * @details  Include the following configurations:
  *             Connection parameters and connection parameters update
  *             Presence of service changed characteristic
  *             Device name
  *             App timer
  *             BLE advertising
  *             UART
  */

#ifndef DEV_CONFIG_H
#define DEV_CONFIG_H

/**
  * All configuration that might be changed frequently should be stored here
  */

#define CFG_DEVICE_NAME                               "nSMART COI"

// Include the service_changed characteristic. If not enabled, the server's database cannot be changed for the lifetime of the device.
#define CFG_IS_SRVC_CHANGED_CHARACT_PRESENT 0 

// Message to send over UART upon startup
#define STARTUP_MESSAGE                               "nRF51 online\n"


/** ===== Pin configuration ===================================================================== */
#define CFG_PIN_UART_TX                               9
#define CFG_PIN_UART_RX                               10
#define CFG_PIN_UART_RTS                              0 // Not using
#define CFG_PIN_UART_CTS                              0 // Not using
#define CFG_PIN_DEBUG_LED_1                           21
#define CFG_PIN_DEBUG_LED_2                           22
#define CFG_PIN_DEBUG_LED_3                           23
#define DEBUG_LED1_ON()                               nrf_gpio_pin_clear(CFG_PIN_DEBUG_LED_1)
#define DEBUG_LED2_ON()                               nrf_gpio_pin_clear(CFG_PIN_DEBUG_LED_2)
#define DEBUG_LED3_ON()                               nrf_gpio_pin_clear(CFG_PIN_DEBUG_LED_3)
#define DEBUG_LED1_OFF()                              nrf_gpio_pin_set(CFG_PIN_DEBUG_LED_1)
#define DEBUG_LED2_OFF()                              nrf_gpio_pin_set(CFG_PIN_DEBUG_LED_2)
#define DEBUG_LED3_OFF()                              nrf_gpio_pin_set(CFG_PIN_DEBUG_LED_3)


/** ===== GAP initialization parameters ========================================================= */

// Minimum acceptable connection interval.
#define CFG_MIN_CONN_INTERVAL_MILISECS                20
// Maximum acceptable connection interval.
#define CFG_MAX_CONN_INTERVAL_MILISECS                75
// Slave latency
#define CFG_SLAVE_LATENCY                             0

// Connection supervisory timeout
//    Note: CFG_CONN_SUP_TIMEOUT_MILISECS has to be greater than 2 times CFG_MAX_CONN_INTERVAL_MILISECS
#define CFG_CONN_SUP_TIMEOUT_MILISECS                 4000


/** ===== App Timer module configuration ======================================================== */
#define CFG_APP_TIMER_PRESCALER                       0
#define CFG_APP_TIMER_OP_QUEUE_SIZE                   4


/** ===== Advertising module configuration ====================================================== */
// See @ref ble_gap_adv_params_t for more notes on the limit of these values

// Advertising interval. In miliseconds
#define CFG_ADVERTISING_INTERVAL_MILISECS             64
// Advertising timeout. In seconds
#define CFG_ADVERTISING_TIMEOUT_SECONDS               BLE_GAP_ADV_TIMEOUT_GENERAL_UNLIMITED


/** ===== Connection Parameters module configuration ============================================ */

// Time from initiating event (connect or start of notification) to first time 
// sd_ble_gap_conn_param_update is called. In miliseconds
#define CFG_CONN_PARAMS_FIRST_UPDATE_DELAY_MILISECS   5000
// Time between each call to sd_ble_gap_conn_param_update after the first call.
#define CFG_CONN_PARAMS_NEXT_UPDATE_DELAY_MILISECS    30000


/** ===== UART module configuration ============================================================= */

// UART TX buffer size in normal operation
//    NOTE: must be a power of 2
#define CFG_UART_TX_BUF_SIZE                          256
// UART RX buffer size in normal operation
//    NOTE: must be a power of 2
#define CFG_UART_RX_BUF_SIZE                          256


// UART TX buffer size while debugging with PCA10028/PCA10031
//    NOTE: must be a power of 2
#define CFG_DEBUG_UART_TX_BUF_SIZE                    8192
// UART RX buffer size while debugging with PCA10028/PCA10031
//    NOTE: must be a power of 2
#define CFG_DEBUG_UART_RX_BUF_SIZE                    8192

// UART baud rate
//    NOTE: Valid values: 
//            1200      2400      4800      9600      14400     19200     28800     38400
//            57600     76800     115200    230400    250000    460800    921600    1M
#define CFG_UART_BAUD_RATE                            115200

#endif // #ifndef DEV_CONFIG_H
