/** @file
  * 
  * @brief    Header file of application-level BLE Advertising module
  *
  * @details  Include:
  *             Advertising module initialization and event handler
  *             Helper function to start advertising
  *
  * BLE stack events should be propagated to the SDK-level BLE Advertising module via the alias
  * function @ref fw_ble_advertising_on_ble_evt()
  *
  */

#ifndef FW_BLE_ADVERTISING_H
#define FW_BLE_ADVERTISING_H

/** ===== Standard library includes ============================================================= */

/** ===== nRF5* SDK includes ==================================================================== */
#include "ble_advdata.h"

/** ===== Non-SDK and non-standard-library includes ============================================= */


/**@brief     Inline function whose only purpose is to call @ref ble_advertising_on_ble_evt(p_ble_evt)
 * @param[in] p_ble_evt  The event received from the BLE stack.
 */
void  fw_ble_advertising_on_ble_evt(ble_evt_t * p_ble_evt);


/**@brief     Inline function serves as alias for @ref ble_advertising_start(BLE_ADV_MODE_FAST)
 * @param[in] p_ble_evt  The event received from the BLE stack.
 */
extern uint32_t __inline fw_ble_advertising_start(void);


/**@brief Function for initializing the Advertising functionality.
 */
void fw_ble_advertising_init(void);

#endif // #ifndef FW_BLE_ADVERTISING_H
