/** @file
  * 
  * @brief    Header file of application-level implementation of GAP, Connection Parameter and BLE Stack
  *
  * @details  Include:
  *             GAP Parameters initialization
  *             Connection Parameter Module initialization and event handler implementation
  *             BLE Stack initialization and event handler implementation
  *
  */

#ifndef FW_BLE_OTHERS_H
#define FW_BLE_OTHERS_H

/** ===== Standard library includes ============================================================= */

/** ===== nRF5* SDK includes ==================================================================== */
#include "app_timer.h"
#include "ble.h"
#include "ble_conn_params.h"

/** ===== Non-SDK and non-standard-library includes ============================================= */


/**@brief   Function for initializing the Connection Parameters module.
 */
void fw_ble_others_conn_params_init(void);

/**@brief   Function for the GAP initialization.
 *
 * @details This function will set up all the necessary GAP (Generic Access Profile) parameters of 
 *          the device. It also sets the permissions and appearance.
 */
void fw_ble_others_gap_params_init(void);

/**@brief Function for the S110 SoftDevice initialization.
 *
 * @details This function initializes the S110 SoftDevice and the BLE event interrupt.
 */
void fw_ble_others_ble_stack_init(void);

#endif // #ifndef FW_BLE_OTHERS_H
