/** @file
  * 
  * @brief    Header file of application-level implementation of BLE Service modules
  *
  * @details  Include:
  *             BLE service modules initialization and event handlers
  *
  * BLE events should be propagated to the BLE service modules via the @ref fw_ble_services_on_ble_evt()
  *
  */

#ifndef FW_BLE_SERVICES_H
#define FW_BLE_SERVICES_H

/** ===== Standard library includes ============================================================= */

/** ===== nRF5* SDK includes ==================================================================== */
#include "ble.h"

/** ===== Non-SDK and non-standard-library includes ============================================= */



/**@brief Function for initializing services that will be used by the application.
 */
void fw_ble_services_init(void);


/** @brief Function for dispatching BLE events to handlers of services interested in them
  */
void fw_ble_services_on_ble_evt(ble_evt_t * p_ble_evt);


/** @brief      Macro for calling error handler function if supplied error code any other than 
  *             NRF_SUCCESS, NRF_ERROR_INVALID_STATE and BLE_ERROR_GATTS_SYS_ATTR_MISSING
  *
  *
  * @param[in]  ERR_CODE Error code supplied to the error handler.
  */    
#define BLE_NOTIFICATION_ERROR_CHECK(ERR_CODE)                      \
    do                                                              \
    {                                                               \
        const uint32_t LOCAL_ERR_CODE = (ERR_CODE);                 \
        if (  (LOCAL_ERR_CODE != NRF_SUCCESS) &&                    \
              (LOCAL_ERR_CODE != NRF_ERROR_INVALID_STATE) &&        \
              (LOCAL_ERR_CODE != BLE_ERROR_GATTS_SYS_ATTR_MISSING)  \
           )                                                        \
        {                                                           \
            APP_ERROR_HANDLER(LOCAL_ERR_CODE);                      \
        }                                                           \
    } while (0)    


#endif // #ifndef FW_BLE_SERVICES_H
