/** @file
  * 
  * @brief    Source file of main application
  *
  * @details  Intended behavior:
  *             Advertise at General Unlimited mode
  *             GATT profile includes:
  *               Device Information Service, showing some basic information about the device
  *               Battery Service, which, as an example, is notified 10 times consecutively 5 seconds
  *                 after a connection with a device has been established
  *
  * 
  *
  */

/** ===== Standard library includes ============================================================= */
#include  <stdint.h>  
#include  <string.h>
#include  <stdio.h>

/** ===== nRF5* SDK includes ==================================================================== */
#include  "nordic_common.h"
#include  "nrf.h"
#include  "nrf_delay.h"
#include  "nrf_gpio.h"
//#include  "ble_hci.h"
//#include  "app_util_platform.h"

/** ===== Non-SDK and non-standard-library includes ============================================= */
#include  "dev_config.h"
#include  "dev_debug_config.h"
#include  "pwm_music.h"
#include  "uart.h"
#include  "fw_ble_advertising.h"
#include  "fw_ble_others.h"
#include  "fw_ble_services.h"


static volatile bool  m_no_tx_buffer = false;




/**@brief Function for the Application's S110 SoftDevice event handler.
 *
 * @param[in] p_ble_evt S110 SoftDevice event.
 */
void on_ble_evt(ble_evt_t * p_ble_evt)
{
  switch (p_ble_evt->header.evt_id)
  {
    case BLE_GAP_EVT_CONNECTED:
    {
      // Example: Set m_test_counter to 49 to trigger a delay in main loop
      printf("BLE_GAP_EVT_CONNECTED\n");
      break;
    }
    
    case BLE_GAP_EVT_DISCONNECTED:
    {
      printf("BLE_GAP_EVT_DISCONNECTED\n");
      break;
    }
    
    case BLE_EVT_TX_COMPLETE:
    {
      m_no_tx_buffer = false;
      printf("BLE_EVT_TX_COMPLETE %d\n", p_ble_evt->evt.common_evt.params.tx_complete.count);
      break;
    }
    
    default:
      // No implementation needed.
      break;
  }
}



APP_PWM_INSTANCE(PWM, 0);
app_pwm_config_t pwm_cfg = APP_PWM_DEFAULT_CONFIG_1CH(500, 1);

void pwm_ready_callback(uint32_t pwm_id)
{
}


/**@brief Application main function.
 */
int main(void)
{
  uint32_t err_code;
  
  // Initialize.
  APP_TIMER_INIT(CFG_APP_TIMER_PRESCALER, CFG_APP_TIMER_OP_QUEUE_SIZE, false);
  uart_init();
  
  
  
  
  
  
  fw_ble_others_ble_stack_init();
  fw_ble_others_gap_params_init();
  fw_ble_services_init();
  fw_ble_advertising_init();
  fw_ble_others_conn_params_init();
  
  
  
  // PWM initialization
  err_code = app_pwm_init(&PWM, &pwm_cfg, pwm_ready_callback);
  APP_ERROR_CHECK(err_code);
  app_pwm_enable(&PWM);
  
  
  printf(STARTUP_MESSAGE);
  

  err_code = fw_ble_advertising_start();
  APP_ERROR_CHECK(err_code);
  
  
  // Enter main loop.
  for (;;)
  {
    nrf_delay_ms(500);
    printf(".");
    
    // Placing the application in low power state while waiting for events.
    UNUSED_VARIABLE(sd_app_evt_wait()); // This func only returns NRF_SUCCESS so no need to handle its return value
  }
}
