/**
  * @file
  *
  * @brief    Source file of application-level UART module
  * 
  * @details  Include UART initialization and UART handler implementation
  * 
  */

#include "uart.h"

/** ===== Standard library includes ============================================================= */

/** ===== nRF5* SDK includes ==================================================================== */
#include "nordic_common.h"

/** ===== Non-SDK and non-standard-library includes ============================================= */



#if ((definedBOARD_PCA10028) || defined(BOARD_PCA10031) && defined(DEBUG))

// UART TX buffer size
#define UART_TX_BUF_SIZE CFG_DEBUG_UART_TX_BUF_SIZE
// UART RX buffer size
#define UART_RX_BUF_SIZE CFG_DEBUG_UART_RX_BUF_SIZE

#else

// UART TX buffer size
#define UART_TX_BUF_SIZE CFG_UART_TX_BUF_SIZE
// UART RX buffer size
#define UART_RX_BUF_SIZE CFG_UART_RX_BUF_SIZE
#endif // #if (definedBOARD_PCA10028) || defined(BOARD_PCA10031) && defined(DEBUG))


#define UART_BAUD_RATE(param_baud_rate)  CONCAT_2(UART_BAUDRATE_BAUDRATE_Baud, param_baud_rate)


/**@brief   Function for handling app_uart events.
 */
static void uart_event_handle(app_uart_evt_t * p_event)
{
}


/**@brief  Function for initializing the UART module.
 */
void uart_init(void)
{
    uint32_t                     err_code;
    const app_uart_comm_params_t comm_params =
    {
        CFG_PIN_UART_RX,
        CFG_PIN_UART_TX,
        CFG_PIN_UART_RTS,
        CFG_PIN_UART_CTS,
        APP_UART_FLOW_CONTROL_DISABLED,
        false,
        UART_BAUD_RATE(CFG_UART_BAUD_RATE)
    };

    APP_UART_FIFO_INIT( &comm_params,
                       UART_RX_BUF_SIZE,
                       UART_TX_BUF_SIZE,
                       uart_event_handle,
                       APP_IRQ_PRIORITY_LOW,
                       err_code);
    APP_ERROR_CHECK(err_code);
    err_code = app_uart_flush();
    APP_ERROR_CHECK(err_code);
}
